# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.3.0

import enum

import winrt.system
from winrt import _winrt_windows_devices_pwm

__all__ = [
    "PwmPulsePolarity",
    "PwmController",
    "PwmPin",
]

class PwmPulsePolarity(enum.IntEnum):
    ACTIVE_HIGH = 0
    ACTIVE_LOW = 1

PwmController = _winrt_windows_devices_pwm.PwmController
PwmPin = _winrt_windows_devices_pwm.PwmPin



# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.3.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.devices.pwm.provider as windows_devices_pwm_provider
import winrt.windows.foundation as windows_foundation
import winrt.windows.foundation.collections as windows_foundation_collections

from winrt.windows.devices.pwm import PwmPulsePolarity

Self = typing.TypeVar('Self')

@typing.final
class PwmController_Static(type):
    def from_id_async(cls, device_id: str, /) -> windows_foundation.IAsyncOperation[PwmController]: ...
    def get_controllers_async(cls, provider: typing.Optional[windows_devices_pwm_provider.IPwmProvider], /) -> windows_foundation.IAsyncOperation[windows_foundation_collections.IVectorView[PwmController]]: ...
    def get_default_async(cls) -> windows_foundation.IAsyncOperation[PwmController]: ...
    @typing.overload
    def get_device_selector(cls) -> str: ...
    @typing.overload
    def get_device_selector(cls, friendly_name: str, /) -> str: ...

@typing.final
class PwmController(winrt.system.Object, metaclass=PwmController_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> PwmController: ...
    def open_pin(self, pin_number: winrt.system.Int32, /) -> typing.Optional[PwmPin]: ...
    def set_desired_frequency(self, desired_frequency: winrt.system.Double, /) -> winrt.system.Double: ...
    @_property
    def actual_frequency(self) -> winrt.system.Double: ...
    @_property
    def max_frequency(self) -> winrt.system.Double: ...
    @_property
    def min_frequency(self) -> winrt.system.Double: ...
    @_property
    def pin_count(self) -> winrt.system.Int32: ...

@typing.final
class PwmPin(winrt.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> PwmPin: ...
    def close(self) -> None: ...
    def get_active_duty_cycle_percentage(self) -> winrt.system.Double: ...
    def set_active_duty_cycle_percentage(self, duty_cycle_percentage: winrt.system.Double, /) -> None: ...
    def start(self) -> None: ...
    def stop(self) -> None: ...
    @_property
    def polarity(self) -> PwmPulsePolarity: ...
    @polarity.setter
    def polarity(self, value: PwmPulsePolarity) -> None: ...
    @_property
    def controller(self) -> typing.Optional[PwmController]: ...
    @_property
    def is_started(self) -> bool: ...

